@@ -31,8 +31,11 @@ class Window(Gtk.ApplicationWindow):
         Gtk.ApplicationWindow.__init__(self,
                                        application=app,
                                        show_menubar=False)
-        
-        self.set_size_request(950, 700)
+
+        if Gdk.Screen.get_default().get_height() < 800:
+            self.maximize()
+        else:
+            self.set_size_request(950, 700)
         self.set_position(Gtk.WindowPosition.CENTER)
         self.set_icon_name("gnome-tweak-tool")
         
@@ -81,6 +84,8 @@ class Window(Gtk.ApplicationWindow):
 
         self._update_decorations (Gtk.Settings.get_default(), None)
 
+        self._group_titlebar_widget = None
+
         self.title = Gtk.Label(label="")
         self.title.get_style_context().add_class("title")
         right_header.set_custom_title(self.title)
@@ -192,10 +197,12 @@ class Window(Gtk.ApplicationWindow):
 
     def _update_decorations(self, settings, pspec):
         layout_desc = settings.props.gtk_decoration_layout;
-        tokens = layout_desc.split(":", 2)
-        if tokens != None:
-                self._right_header.props.decoration_layout = ":" + tokens[1]
-                self._left_header.props.decoration_layout = tokens[0]
+        tokens = layout_desc.split(":", 1)
+        if len(tokens) > 1:
+            self._right_header.props.decoration_layout = ":" + tokens[1]
+        else:
+            self._right_header.props.decoration_layout = ""
+        self._left_header.props.decoration_layout = tokens[0]
 
     def _after_key_press(self, widget, event):
         if not self.button.get_active() or not self.entry.is_focus():
@@ -247,6 +254,14 @@ class Window(Gtk.ApplicationWindow):
             group = row.get_child().get_text()
             self.stack.set_visible_child_name(group)
             self.title.set_text(group)
+            tweakgroup = self._model.get_value(
+                                self._model.get_tweakgroup_iter(group),
+                                self._model.COLUMN_TWEAK)
+            if self._group_titlebar_widget:
+                self._right_header.remove(self._group_titlebar_widget)
+            self._group_titlebar_widget = tweakgroup.titlebar_widget
+            if self._group_titlebar_widget:
+                self._right_header.pack_end(self._group_titlebar_widget)
 
     def _on_find_toggled(self, btn):
          if self.searchbar.get_search_mode():
